@@ -91,7 +91,7 @@ setMethod("add.gaps", "multiphyDat", function(x, ...){
     x@seq <- lapply(x@seq, form.dna.phyDat, x@labels)
 
     ## update number of sequences ##
-    x@n.seq <- as.integer(sum(sapply(x@seq, length)))
+    x@n.seq <- as.integer(sum(lengths(x@seq)))
     x@n.seq.miss <- .nMissingSequences(x@seq)
 
     ## RETURN OBJECT ##
